function [tot_score] = compute_error(p,XArray,YArray,XS,YS)
% p is a vector with the stretch (alpha) and translate (beta) parameters
% XArray and YArray are the spline arrays
% XS and YS are the spline intervals (e.g., [0 119] for alpha and [0 165] for mutant)

alpha = p(1);
beta = p(2);

% find start and end-points of curve over which to integrate
c_start = max(XS(1),YS(1)*alpha + beta);
c_end = min(XS(2),YS(2)*alpha + beta);

if alpha <= 0.2 | (c_start >= c_end) | alpha > 5,
    tot_score = 10^6;
    return;
end;

knots = size(XArray,1);
kt = (YS(2)-YS(1))/knots;
qt = YS(1):kt:YS(2);

ks = (XS(2)-XS(1))/knots;
qs = XS(1):ks:XS(2);

XEP = zeros(knots,2);
for i=1:knots,
    XEP(i,1) = qs(i);
    XEP(i,2) = qs(i+1);
end;

YEP = zeros(knots,2);
qtt = alpha*qt + beta;
for i=1:knots, 
    YEP(i,1) = max(XS(1),qtt(i));
    YEP(i,2) = min(XS(2),qtt(i+1));
end;

int_start = max(XS(1),qtt(1));
int_end = min(XS(2),qtt(knots+1));

support_prods_rt = zeros(knots,knots);
support_prods_lt = zeros(knots,knots);

% compute overlap intervals
for i=1:knots,
    for j=1:knots,
        lp = max(XEP(i,1),YEP(j,1));
        rp = min(XEP(i,2),YEP(j,2));
        if rp > lp,
            support_prods_rt(i,j) = rp;
            support_prods_lt(i,j) = lp;
        else,
            support_prods_rt(i,j) = inf;
            support_prods_lt(i,j) = inf;
        end;
    end;
end;

tot_score = 0;
tot_genes = size(XArray,3);

% loop through genes and compute the scores
    for k2=1:tot_genes,
        X = XArray(:,:,k2);
        Y = YArray(:,:,k2);
    
        v = 0;
        % compute f*g
        fg = 0;
        for i=1:knots,
            for j=1:knots,
                if isinf(support_prods_rt(i,j)) == 0,
                    a3 = X(i,1); a2 = X(i,2); a1 = X(i,3); a0 = X(i,4);
                    b3 = Y(j,1); b2 = Y(j,2); b1 = Y(j,3); b0 = Y(j,4);
   
                    c7 = 1/7*b3/alpha^3/kt^3*a3/ks^3;
                    c6 = 1/6*((3*b3*(-1/alpha*beta-qt(j))/alpha^2/kt^3+b2/alpha^2/kt^2)*a3/ks^3+b3/alpha^3/kt^3*(-3*a3*qs(i)/ks^3+a2/ks^2));
                    c5 = 1/5*((3*b3*(-1/alpha*beta-qt(j))^2/alpha/kt^3+b1/alpha/kt+2*b2*(-1/alpha*beta-qt(j))/alpha/kt^2)*a3/ks^3+(3*b3*(-1/alpha*beta-qt(j))/alpha^2/kt^3+b2/alpha^2/kt^2)*(-3*a3*qs(i)/ks^3+a2/ks^2)+b3/alpha^3/kt^3*(3*a3*qs(i)^2/ks^3+a1/ks-2*a2*qs(i)/ks^2));
                    c4 = 1/4*((b3*(-1/alpha*beta-qt(j))^3/kt^3+b0+b1*(-1/alpha*beta-qt(j))/kt+b2*(-1/alpha*beta-qt(j))^2/kt^2)*a3/ks^3+(3*b3*(-1/alpha*beta-qt(j))^2/alpha/kt^3+b1/alpha/kt+2*b2*(-1/alpha*beta-qt(j))/alpha/kt^2)*(-3*a3*qs(i)/ks^3+a2/ks^2)+(3*b3*(-1/alpha*beta-qt(j))/alpha^2/kt^3+b2/alpha^2/kt^2)*(3*a3*qs(i)^2/ks^3+a1/ks-2*a2*qs(i)/ks^2)+b3/alpha^3/kt^3*(-a3/ks^3*qs(i)^3+a0-a1/ks*qs(i)+a2/ks^2*qs(i)^2));
                    c3 = 1/3*((b3*(-1/alpha*beta-qt(j))^3/kt^3+b0+b1*(-1/alpha*beta-qt(j))/kt+b2*(-1/alpha*beta-qt(j))^2/kt^2)*(-3*a3*qs(i)/ks^3+a2/ks^2)+(3*b3*(-1/alpha*beta-qt(j))^2/alpha/kt^3+b1/alpha/kt+2*b2*(-1/alpha*beta-qt(j))/alpha/kt^2)*(3*a3*qs(i)^2/ks^3+a1/ks-2*a2*qs(i)/ks^2)+(3*b3*(-1/alpha*beta-qt(j))/alpha^2/kt^3+b2/alpha^2/kt^2)*(-a3/ks^3*qs(i)^3+a0-a1/ks*qs(i)+a2/ks^2*qs(i)^2));
                    c2 = 1/2*((b3*(-1/alpha*beta-qt(j))^3/kt^3+b0+b1*(-1/alpha*beta-qt(j))/kt+b2*(-1/alpha*beta-qt(j))^2/kt^2)*(3*a3*qs(i)^2/ks^3+a1/ks-2*a2*qs(i)/ks^2)+(3*b3*(-1/alpha*beta-qt(j))^2/alpha/kt^3+b1/alpha/kt+2*b2*(-1/alpha*beta-qt(j))/alpha/kt^2)*(-a3/ks^3*qs(i)^3+a0-a1/ks*qs(i)+a2/ks^2*qs(i)^2));
                    c1 = (b3*(-1/alpha*beta-qt(j))^3/kt^3+b0+b1*(-1/alpha*beta-qt(j))/kt+b2*(-1/alpha*beta-qt(j))^2/kt^2)*(-a3/ks^3*qs(i)^3+a0-a1/ks*qs(i)+a2/ks^2*qs(i)^2);
            
                    s = support_prods_rt(i,j);
                    fg = fg + [c7 c6 c5 c4 c3 c2 c1]*[s^7 s^6 s^5 s^4 s^3 s^2 s]';
                    s = support_prods_lt(i,j);
                    fg = fg - [c7 c6 c5 c4 c3 c2 c1]*[s^7 s^6 s^5 s^4 s^3 s^2 s]';
                end;
            end;
        end;

        v = -2*fg;

        % compute g^2
        g2 = 0;
        for i=1:knots,
            lt = max(qs(i),int_start);
            rt = min(qs(i+1),int_end);
    
            if lt < rt,    
                a3 = X(i,1); a2 = X(i,2); a1 = X(i,3); a0 = X(i,4);
                c7 = 1/7*a3^2/ks^6;
                c6 = 1/3*(-3*a3*qs(i)/ks^3+a2/ks^2)*a3/ks^3;
                c5 = 1/5*(2*(3*a3*qs(i)^2/ks^3+a1/ks-2*a2*qs(i)/ks^2)*a3/ks^3+(-3*a3*qs(i)/ks^3+a2/ks^2)^2);
                c4 = 1/4*(2*(-a3/ks^3*qs(i)^3+a0-a1/ks*qs(i)+a2/ks^2*qs(i)^2)*a3/ks^3+2*(3*a3*qs(i)^2/ks^3+a1/ks-2*a2*qs(i)/ks^2)*(-3*a3*qs(i)/ks^3+a2/ks^2));
                c3 = 1/3*(2*(-a3/ks^3*qs(i)^3+a0-a1/ks*qs(i)+a2/ks^2*qs(i)^2)*(-3*a3*qs(i)/ks^3+a2/ks^2)+(3*a3*qs(i)^2/ks^3+a1/ks-2*a2*qs(i)/ks^2)^2);
                c2 = (-a3/ks^3*qs(i)^3+a0-a1/ks*qs(i)+a2/ks^2*qs(i)^2)*(3*a3*qs(i)^2/ks^3+a1/ks-2*a2*qs(i)/ks^2);
                c1 = (-a3/ks^3*qs(i)^3+a0-a1/ks*qs(i)+a2/ks^2*qs(i)^2)^2;
        
                s = rt;
                g2 = g2 + [c7 c6 c5 c4 c3 c2 c1]*[s^7 s^6 s^5 s^4 s^3 s^2 s]';
                s = lt;
                g2 = g2 - [c7 c6 c5 c4 c3 c2 c1]*[s^7 s^6 s^5 s^4 s^3 s^2 s]';
            end;
        end;
        
        v = v + g2;

        % compute f^2
        f2 = 0;
        for i=1:knots,
            lt = max(qtt(i),int_start);
            rt = min(qtt(i+1),int_end);
    
            if lt < rt,
                b3 = Y(i,1); b2 = Y(i,2); b1 = Y(i,3); b0 = Y(i,4);
        
                c7 = 1/7*b3^2/alpha^6/kt^6;
                c6 = 1/3*(3*b3*(-1/alpha*beta-qt(i))/alpha^2/kt^3+b2/alpha^2/kt^2)*b3/alpha^3/kt^3;
                c5 = 1/5*(2*(3*b3*(-1/alpha*beta-qt(i))^2/alpha/kt^3+b1/alpha/kt+2*b2*(-1/alpha*beta-qt(i))/alpha/kt^2)*b3/alpha^3/kt^3+(3*b3*(-1/alpha*beta-qt(i))/alpha^2/kt^3+b2/alpha^2/kt^2)^2);
                c4 = 1/4*(2*(b3*(-1/alpha*beta-qt(i))^3/kt^3+b0+b1*(-1/alpha*beta-qt(i))/kt+b2*(-1/alpha*beta-qt(i))^2/kt^2)*b3/alpha^3/kt^3+2*(3*b3*(-1/alpha*beta-qt(i))^2/alpha/kt^3+b1/alpha/kt+2*b2*(-1/alpha*beta-qt(i))/alpha/kt^2)*(3*b3*(-1/alpha*beta-qt(i))/alpha^2/kt^3+b2/alpha^2/kt^2));
                c3 = 1/3*(2*(b3*(-1/alpha*beta-qt(i))^3/kt^3+b0+b1*(-1/alpha*beta-qt(i))/kt+b2*(-1/alpha*beta-qt(i))^2/kt^2)*(3*b3*(-1/alpha*beta-qt(i))/alpha^2/kt^3+b2/alpha^2/kt^2)+(3*b3*(-1/alpha*beta-qt(i))^2/alpha/kt^3+b1/alpha/kt+2*b2*(-1/alpha*beta-qt(i))/alpha/kt^2)^2);
                c2 = (b3*(-1/alpha*beta-qt(i))^3/kt^3+b0+b1*(-1/alpha*beta-qt(i))/kt+b2*(-1/alpha*beta-qt(i))^2/kt^2)*(3*b3*(-1/alpha*beta-qt(i))^2/alpha/kt^3+b1/alpha/kt+2*b2*(-1/alpha*beta-qt(i))/alpha/kt^2);
                c1 = (b3*(-1/alpha*beta-qt(i))^3/kt^3+b0+b1*(-1/alpha*beta-qt(i))/kt+b2*(-1/alpha*beta-qt(i))^2/kt^2)^2;
        
                s = rt;
                v = v + [c7 c6 c5 c4 c3 c2 c1]*[s^7 s^6 s^5 s^4 s^3 s^2 s]';
                s = lt;
                v = v - [c7 c6 c5 c4 c3 c2 c1]*[s^7 s^6 s^5 s^4 s^3 s^2 s]';
            end;
        end;
        
        v = v + f2;
        
        tot_score = tot_score + v;
    end;
    
% the final score is averaged over the number of genes and the length of overlap (c_end - c_start)
tot_score = tot_score / (tot_genes*(c_end-c_start));
tot_score
p