function [center, obj_fcn, U] = stepkm(center, data)
%STEPKM One step in k-means clustering.
%	[CENTER, ERR] = STEPKM(CENTER, DATA)
%	performs one iteration of k-means clustering, where
%
%	DATA: matrix of data to be clustered. (Each row is a data point.)
%	CENTER: center of clusters. (Each row is a center.)
%	ERR: objective function for parititon U.

center_n = size(center, 1);
data_n = size(data, 1);
dim_n = size(data, 2);

% ====== Find the U (partition matrix)
dist = vecdist(center, data);		% fill the distance matrix
[a,b] = min(dist);
index = b+center_n*(0:data_n-1);
U = zeros(size(dist));
U(index) = ones(size(index));

% ====== Find the new centers
center = (U*data)./(sum(U')'*ones(1,dim_n));

% ====== Find the new objective function
dist = vecdist(center, data);			% fill the distance matrix
obj_fcn = sum(sum((dist.^2).*U));		% objective function
