function [numTotalRand, numRandWorse] = CmpRandWithActual(randomFile,actualFile)
% compare the results of a rigorous method (GCV+AL, say) of estimating
% time-points against just randomly choosing point-sets. Returns the
% total number of random point-sets and, out of these, the number of
% random point-sets that perform worse than the rigorous method
% IN:
% actualFile: the datafile containing the results of the rigorous method. it should
%  have the variables numFinalSamples, finalCI, and strategy. currently only
%  strategy="gcv-activelearning" is supported
% randomFile: the datafile containing results of random tries. it
%  should have the variables numFinalSamples, numRandomTries and all_err
% OUT:
% numTotalRand: number of random tries made in total
% numRandWorse: number of random tries that do worse than the rigorous
% method

if (nargin<2)
  error('CmpRandWithActual: insufficient arg list');
end

actl = load(actualFile);
rndm = load(randomFile);

if (actl.numFinalSamples ~= rndm.numFinalSamples)
  error('CmpRandWithActual: need to have same numFinalSamples in both');
end

if (~strfind(actl.strategy,'gcv-activelearning'))
  error('CmpRandWithActual: only implemented strategy="gcv-activelearning" yet');
end

rerr = rndm.all_err;
x1 = actl.finalCI;
acterr = x1(1); % the first element should have it

r1 = sort(rerr);
numTotalRand = length(r1);
numRandWorse =length( find ( r1 > acterr));
