function score = GCV(A, D, C, cost)
% compute the generalized cross-validation score (Cummins, 2001)
% inputs:
% A - the A matrix for this lambda / timepoint combination
% D - the matrix of original expression values (rows = genes, cols
%     = experiments) for the experiments used to smooth
% C - the matrix containing an estimated expression level for each gene,
%     for each experiment represented in D
% cost - optional argument. if < 1, it encourages use of more control
% points than would be otherwise used
% outputs:
% score = the scalar score for the generalized cross validation

% determine the number of timepoints we're using
n = size(D, 2);

% determine the number of genes we're using
nGenes = size(D, 1);

% take the difference between the observed values and the estimated values
% and compute the element-wise square
sqDiff = (D - C).^2;

% sum over all time points = columns
tpSum = sum(sqDiff, 2);

% compute a normalizing factor
norm = (1/n) / (1 -  cost* (trace(A)/n) )^2;
%norm = (1/n) / (1 -  cost* (trace(A)/n) )^1.5;

% build a vector full of them
norm = norm * ones(nGenes, 1);

% normalize the sums of squared residuals 
geneGCV = tpSum.*norm;

% return the sum over all genes' GCVs
score = sum(geneGCV);
