function PlotData(D, Na, Id)
% PlotData(D, Na) plots a 3-cluster data-matrix D onto a 3x1
% plot. If the Na is not supplied, then first 1/3rd elements
% make up one cluster, 2nd 1/3rd elements make the second cluster and
% so on. In Na *is* supplied then if [n T] = size(D), then Na should be
% n x 1 with min value =1 and max value = 3 (thus indicating clustering info)


N = size(D,1);
x = floor( N /3 );
if (nargin < 2 | sum(Na)==0)
  Na = [ones(x,1)*1 ; ones(x,1)*2; ones(N-2*x,1)*3];
end


if (min(size(Na))~=1 | min(Na) ~= 1 | max(Na) ~= 3)
  fprintf(2,'Bad Na');
  return;
end

if (size(Na,1) == 1)
  Na = Na';
end

cl1 = find(Na==1);
cl2 = find(Na==2);
cl3 = find(Na==3);

cl1Mean = sum( D(cl1,:), 1) / size(cl1,1);
cl2Mean = sum( D(cl2,:), 1) / size(cl2,1);
cl3Mean = sum( D(cl3,:), 1) / size(cl3,1);

for i=1:size(cl1,1)
  subplot(3,1,1);
  plot(D(cl1(i),:),'g');
%  plotAxis = axis;
  hold on;
end
if (nargin<3)
  plot(cl1Mean, 'b', 'LineWidth', 3);
else
  plot(Id(cl1(1),:), 'b', 'LineWidth', 3);
end
v=axis;
axis([v(1) v(2) -1.5 1.5]);
hold off;

for i=1:size(cl2,1)
  subplot(3,1,2);
  plot(D(cl2(i),:),'g');
%  axis(plotAxis);
  hold on;
end
if (nargin < 3)
  plot(cl2Mean, 'b', 'LineWidth', 3);
else
  plot(Id(cl2(1),:), 'b', 'LineWidth', 3);
end
v=axis;
axis([v(1) v(2) -1.5 1.5]);
hold off;

for i=1:size(cl3,1)
  subplot(3,1,3);
  plot(D(cl3(i),:),'g');
%  axis(plotAxis);
  hold on;
end
if (nargin < 3)
  plot(cl3Mean, 'b', 'LineWidth', 3);
else
  plot(Id(cl3(1),:), 'b', 'LineWidth', 3);
end
v=axis;
axis([v(1) v(2) -1.5 1.5]);
hold off;
