function PlotDataEst(estD, actualD, Na)
% PlotDataEst(estD, actualD, Na) plots a 3-cluster data-matrix estD onto a 3x1
% plot. It plots the actual data actualD side by side in another 3x1
% plot.
% If the Na is not supplied, then first 1/3rd elements
% make up one cluster, 2nd 1/3rd elements make the second cluster and
% so on. In Na *is* supplied then if [n T] = size(D), then Na should be
% n x 1 with min value =1 and max value = 3 (thus indicating clustering info)


N = size(estD,1);
x = floor( N /3 );
if (nargin < 3)
  Na = [ones(x,1)*1 ; ones(x,1)*2; ones(N-2*x,1)*3];
end


if (min(size(Na))~=1 | min(Na) ~= 1 | max(Na) ~= 3)
  print 'Bad Na'
  return
end

if (size(Na,1) == 1)
  Na = Na';
end

cl1 = find(Na==1);
cl2 = find(Na==2);
cl3 = find(Na==3);

est_cl1Mean = sum( estD(cl1,:), 1) / size(cl1,1);
est_cl2Mean = sum( estD(cl2,:), 1) / size(cl2,1);
est_cl3Mean = sum( estD(cl3,:), 1) / size(cl3,1);

actual_cl1Mean = sum( actualD(cl1,:), 1) / size(cl1,1);
actual_cl2Mean = sum( actualD(cl2,:), 1) / size(cl2,1);
actual_cl3Mean = sum( actualD(cl3,:), 1) / size(cl3,1);

for i=1:size(cl1,1)
  subplot(3,2,1);
  plot(estD(cl1(i),:),'r');
  r1a = axis;
  hold on;
end
plot(est_cl1Mean, 'b', 'LineWidth', 3);
title('Estimated','FontSize',14);  

for i=1:size(cl1,1)
  subplot(3,2,2);
  plot(actualD(cl1(i),:),'r');
  r1b = axis;
  hold on;
end
plot(actual_cl1Mean, 'b', 'LineWidth', 3);
hold off;
title('Actual','FontSize',14);  

r1 = [ min(r1a(1),r1b(1)) max(r1a(2),r1b(2)) min(r1a(3),r1b(3)) max(r1a(4),r1b(4))];
subplot(3,2,1);
axis(r1);
subplot(3,2,2);
axis(r1);


for i=1:size(cl2,1)
  subplot(3,2,3);
  plot(estD(cl2(i),:),'r');
  r2a = axis;
  hold on;
end
plot(est_cl2Mean, 'b', 'LineWidth', 3);

hold off;

for i=1:size(cl2,1)
  subplot(3,2,4);
  plot(actualD(cl2(i),:),'r');
  r2b = axis;
  hold on;
end
plot(actual_cl2Mean, 'b', 'LineWidth', 3);

hold off;

r2 = [ min(r2a(1),r2b(1)) max(r2a(2),r2b(2)) min(r2a(3),r2b(3)) max(r2a(4),r2b(4))];
subplot(3,2,3);
axis(r2);
subplot(3,2,4);
axis(r2);


for i=1:size(cl3,1)
  subplot(3,2,5);
  plot(estD(cl3(i),:),'r');
  r3a = axis;
  hold on;
end
plot(est_cl3Mean, 'b', 'LineWidth', 3);

hold off;

for i=1:size(cl3,1)
  subplot(3,2,6);
  plot(actualD(cl3(i),:),'r');
  r3b = axis;
  hold on;
end
plot(actual_cl3Mean, 'b', 'LineWidth', 3);

r3 = [ min(r3a(1),r3b(1)) max(r3a(2),r3b(2)) min(r3a(3),r3b(3)) max(r3a(4),r3b(4))];
subplot(3,2,5);
axis(r3);
subplot(3,2,6);
axis(r3);


hold off;
