% each data point is supposed to be spread over 2 hours, with 5 min
% intervals. i.e. 24 samples . There are 3 clusters in each data, one
% of which is just a flat line, always

T = 24;
times = 0:T-1;

% the max is typically 1. and the std dev is always 0.2
rng = 1;
stdDev = 0;%0.2;
totalSize = 150;
numClusters = 3;
clusterSize = totalSize/ numClusters;

% first data sample
% 150 x 24
% first cluster is a sinusoid, with period 1hr and 0 at time=0, max =1,
% second cluster is a sinusoid, with period 1hr and 1 at time=0, max =1
% third cluster is a straight line, y=0

a1 = [0:11 0:11] * 2 *pi / 12; % 0..2pi over 2 cycles
X1 = rng*repmat(sin(a1), clusterSize,1) + stdDev*randn(clusterSize,T);
K1 = sin(a1);

a2 = [3:11 0:11 0:2] * 2 * pi/ 12; %0..2pi over 2 cycles, with phase
                                   %pi/2
X2 = rng*repmat(sin(a2), clusterSize,1) + stdDev*randn(clusterSize,T);
K2 = sin(a2);

X3 = stdDev*randn(clusterSize,T);
K3 = zeros(1,T);

idealA = [X1; X2; X3];
clustersA = [K1; K2; K3];




% second data sample
% 150 x 24
% first cluster is a sinusoid (period: 1hr) for 1 hr and then flat for next hour
% second cluster is flat for 1hr and then a sinusoid (period: 1hr) for next hr
% third cluster is straight line y=0

%ACTUALLY: I generated it wrong, but since I have it and it gives an
%interesting result...might as well use it..

a1 = [0:11 zeros(1,12)] ; % will use sin(0) = 0
X1 = rng*repmat(sin(a1), clusterSize,1) + stdDev*randn(clusterSize,T);
K1 = sin(a1);

a2 = [zeros(1,12) 0:11];
X2 = rng*repmat(sin(a2), clusterSize,1) + stdDev*randn(clusterSize,T);
K2 = sin(a2);

X3 = stdDev*randn(clusterSize,T);
K3 = zeros(1,T);

idealB = [X1; X2; X3];
clustersB = [K1; K2; K3];


% third data sample
% 150 x 24
% first cluster is a sinusoid (period: 2hr) over 2 hrs and 0 at time=0
% second cluster is a sinusoid (period: 1hr) over 2 hrs and 0 at time=0
% third cluster is a straight line y=0

a1 = [0:23] * 2 *pi / 24; % 0..2pi over 1 cycle
X1 = rng*repmat(sin(a1), clusterSize,1) + stdDev*randn(clusterSize,T);
K1 = sin(a1);

a2 = [0:11 0:11]* 2 * pi/ 12; %0..2pi over 2 cycles with phase =0
X2 = rng*repmat(sin(a2), clusterSize,1) + stdDev*randn(clusterSize,T);
K2 = sin(a2);

X3 = stdDev*randn(clusterSize,T);
K3 = zeros(1,T);

idealC = [X1; X2; X3];
clustersC = [K1; K2; K3];

% fourth data sample
% 150 x 24
% first cluster is flat from 0m:30m, a sinusoid (period: 1hr) from
% 30m:90m and flat from 90m:120m (30m = 30 min)
% second cluster is same as first cluster except sinusoid is phase
% shifted by 180 degress
% third cluster is flat

a1 = [zeros(1,6) 0:11 zeros(1,6)] * 2 *pi / 12; % 0..2pi over 1 cycle
X1 = rng*repmat(sin(a1), clusterSize,1) + stdDev*randn(clusterSize,T);
K1 = sin(a1);

X2 = -X1;
K2 = -K1;

X3 = stdDev*randn(clusterSize,T);
K3 = zeros(1,T);

idealD = [X1; X2; X3];
clustersD = [K1; K2; K3];

% fifth data sample
% 150 x 24
% first cluster is a sinusoid (period: 1hr) for 1 hr and then flat for next hour
% second cluster is a negative sinusoid (period: 1hr) for 1 hr and then flat for next hr
% third cluster is straight line y=0

a1 = [0:11 zeros(1,12)] * 2 * pi / 12; % will use sin(0) = 0
X1 = rng*repmat(sin(a1), clusterSize,1) + stdDev*randn(clusterSize,T);
K1 = sin(a1);

a2 = -a1;
X2 = rng*repmat(sin(a2), clusterSize,1) + stdDev*randn(clusterSize,T);
K2 = sin(a2);

X3 = stdDev*randn(clusterSize,T);
K3 = zeros(1,T);

idealE = [X1; X2; X3];
clustersE = [K1; K2; K3];


% sixth data sample
% 150 x 24
% first cluster is a sinusoid (period: 1hr) for 1 hr and then flat for next hour
% second cluster is flat for 1 hr and then a sinusoid (period: 1hr) for next hr
% third cluster is straight line y=0

a1 = [0:11 zeros(1,12)] * 2 * pi / 12; % will use sin(0) = 0
X1 = rng*repmat(sin(a1), clusterSize,1) + stdDev*randn(clusterSize,T);
K1 = sin(a1);

a2 = [zeros(1,12) 1:12] * 2 * pi / 12; % will use sin(0) = 0 
X2 = rng*repmat(sin(a2), clusterSize,1) + stdDev*randn(clusterSize,T);
K2 = sin(a2);

X3 = stdDev*randn(clusterSize,T);
K3 = zeros(1,T);

idealF = [X1; X2; X3];
clustersF = [K1; K2; K3];


%seventh data sample
% 150 x 24
% first cluster is a sinusoid (period: 1hr) for 1 hr and then flat for next hour
% second cluster is same as first, except negative
% third cluster is straight line y=0

a1 = [0:11 zeros(1,12)] ; % will use sin(0) = 0
X1 = rng*repmat(sin(a1), clusterSize,1) + stdDev*randn(clusterSize,T);
K1 = sin(a1);

a2 = [0:11 zeros(1,12)] ; % will use sin(0) = 0
X2 = -rng*repmat(sin(a2), clusterSize,1) + stdDev*randn(clusterSize,T);
K2 = sin(a2);

X3 = stdDev*randn(clusterSize,T);
K3 = zeros(1,T);

idealG = [X1; X2; X3];
clustersG= [K1; K2; K3];


%eighth data sample
% 150 x 24
% first cluster is a sinusoid (period: 40min) for and then flat for next hour
% second cluster is same as first, except negative
% third cluster is straight line y=0

a1 = [0:7 zeros(1,16)] * 2 *pi / 8;
X1 = rng*repmat(sin(a1), clusterSize,1) + stdDev*randn(clusterSize,T);
K1 = sin(a1);

a2 = -a1;
X2 = rng*repmat(sin(a2), clusterSize,1) + stdDev*randn(clusterSize,T);
K2 = sin(a2);

X3 = stdDev*randn(clusterSize,T);
K3 = zeros(1,T);

idealH = [X1; X2; X3];
clustersH = [K1; K2; K3];


%seventh data sample
% 150 x 24
% first cluster is a damped sinusoid (period: 1hr) for 1 hr and then flat for next hour
% second cluster is same as first, except negative
% third cluster is straight line y=0

a1 = [0:11 zeros(1,12)] ; % will use sin(0) = 0
b1 = [9:-0.5:3.5 zeros(1,12)]/9.0 .* sin(a1);
X1 = rng*repmat(b1, clusterSize,1) + stdDev*randn(clusterSize,T);
K1 = sin(a1);

a2 = [0:11 zeros(1,12)] ; % will use sin(0) = 0
b2 = [9:-0.5:3.5 zeros(1,12)]/9.0 .* sin(a2);
X2 = -rng*repmat(b2, clusterSize,1) + stdDev*randn(clusterSize,T);
K2 = sin(a2);

X3 = stdDev*randn(clusterSize,T);
K3 = zeros(1,T);

idealI = [X1; X2; X3];
clustersI= [K1; K2; K3];

save SimIdeal ideal* clusters*;
				  
