%
function  [c,Na,sig] = inter(Nv1,Nv2,clNum,grid,epsilon,times,times2,reRun,startName);
% Nv1 - values for first dataset
% Nv2 - values for second dataset
% Nv1 and Nv2 should have the same number of genes, though they can
% contain different number of columns (experiments). The reason we have 
% two inputs datasets and not one is in order to filter out genes 
% that have many missing values in either of them. The current version 
% interpolates ONLY Nv1. If you would like to interpolate Nv2, 
% you can either need re-run this file, and change the identiy of Nv1
% and Nv2, or use a second set of files, which uses the same classes 
% found for Nv1 to interpolate Nv2. 
% clNum - number of classes
% grid - number of grid points (= control points - 2) 
% epsilon - the difference for convergence (when should the EM stop)
% times - the time points of the different experiments
% times2 - the sequence indicating the start and end of *all*
% experiments. only times2(1) and times2(end) are used
% reRun - number of time to initialize the EM algorithm (the results is 
% the model that achieves the highest likelihood)
% startName - initial for the output file name

% -----------------------------------------------------
% The output is written to a file ('[startName]splines.bin') which
% can be evaluated using the function 'evalPol'
% ------------------------------------------------------- 

  Y1 = Nv1;
  Y2 = Nv2;
  [totG,expNum] = size(Y1); 
  expNum2 = size(Nv2,2);
  numVals1 = sum(Y1' < 90,1);
  numVals2 = sum(Y2' < 90,1);
  Y = Y1(numVals1 > 3*expNum/4 & numVals2>3*expNum2/4,:);
  Na = [1:totG]*0;
  Na(numVals1 > 3*expNum/4 & numVals2>3*expNum2/4) = 1;

  geneNum = size(Y,1);
  grid = grid + 2;
  gridVals = [0:grid-1];
  t1 = [1:expNum];
  % OLD
  % t1 = (times-times(1))*(grid-3)/(times(expNum)-times(1)) + 1
  % NEW
  t1 = (times-times2(1))*(grid-3)/(times2(end)-times2(1)) + 1;
  t = repmat(t1',1,geneNum);
  Y = Y';
  numVals = sum(Y < 90,1); 
  t(Y > 90) = 0;
  Y(Y > 90) = 0;
  inp = Y;
% numVals is the number of observed values for each gene
  AllS = zeros(expNum,grid,geneNum); 
% spline matrix with all coef'
 origS = createS(t1,gridVals,grid,expNum);
 for i=1:geneNum,
   AllS(:,:,i) = createS(t(:,i),gridVals,grid,expNum);
 end
 bestVal = -10000;
 for rer=1:reRun,
   Gamma = zeros(grid,geneNum,clNum);
   Theta = ones(grid,grid,clNum);
   for i=1:clNum,
	Theta(:,:,i) = diag(ones(grid,1)*1,0);
%        Theta(:,:,i) = Theta(:,:,i) + .5;
   end
   Mue = zeros(grid,clNum);
   sig = .1; 
   diff = 100000;
   pre = -10000000;
   prob = zeros(clNum,geneNum);
   assign = 1;
   while assign<(clNum+1),
    r = random('Discrete Uniform',geneNum,1,1);
    if sum(t(:,r) ~= 0) == expNum
        
        % if the reciprocal condition of the matrix is below the floating
        % point error on the system, then we can't rely on the result of
        % inverting the matrix, and need to bail out.  you can use a
        % try ... catch ... end block in the code that calls either this
        % function, or by extension, contRep, to catch this condition and
        % deal with it appropriately.
        if ( rcond((AllS(:,:,r)'*AllS(:,:,r))) < eps)
            error('inter.m:SingularMatrix', 'inter.m:SingularMatrix');
        end
        
       Mue(:,assign) = (AllS(:,:,r)'*AllS(:,:,r))^(-1)*(AllS(:,:,r)'*inp(:,r)); 
       assign = assign + 1;
    end
   end
    prob = findProb(inp,AllS,Mue,Gamma,geneNum,Theta,sig,clNum,grid,numVals);
    st = 1; 
    while diff > epsilon
      if st > 1
        Mue = findMue(inp,AllS,Gamma,geneNum,clNum,grid,expNum,prob);
        sig = findSigma(inp,AllS,Mue,Gamma,geneNum,numVals,clNum,prob,Theta,sig);
        if sig < .01
	  sig = .01;
        end     
	Theta = findTheta(Gamma,AllS,sig,geneNum,clNum,prob,st,Theta);
	st = st + 1;
      end
      Gamma = findGamma(inp,AllS,Mue,geneNum,Theta,sig,grid,clNum,prob);
      prob = findProb(inp,AllS,Mue,Gamma,geneNum,Theta,sig,clNum,grid,... 
		      numVals);
      cur = compLog(inp,AllS,Gamma,Mue,Theta,geneNum,sig,numVals,...
		    clNum,grid,prob);
      diff = abs(cur - pre);
      pre = cur;
      st = st + 1;
   end
   if cur > bestVal
     saveP = prob;
     saveMue = Mue;
     saveGamma = Gamma;
     bestVal = cur;
   end
 end
 Mue = saveMue;
 Gamma = saveGamma;
 prob = saveP;
 curves = zeros(grid-3,4,geneNum);
 c = [1:geneNum];
 cP1 = zeros(geneNum,grid);
 cP2 = zeros(geneNum,grid);
 pl = 1;
 for i=1:geneNum,
     [m,c(i)] = max(prob(:,i));
     cP1(i,:) = Mue(:,c(i))';
     cP2(i,:)= squeeze(Gamma(:,i,c(i)))';
     curves(:,:,i) = findCurve(Mue(:,c(i)),Gamma(:,i,c(i)),grid);
     while Na(pl) == 0
       pl = pl + 1;
     end
     Na(pl) = c(i);
     pl = pl + 1;
 end
 fileName = [startName 'Splines.bin'] ;
 fid = fopen(fileName,'wb');
 fwrite(fid,size(curves),'int');
 fwrite(fid,curves,'float');
 fclose(fid);
 fileName = [startName 'Ass.txt'];
 dlmwrite(fileName,Na,'\n');
 fclose('all');
 avg = zeros(clNum,expNum);
 for i=1:clNum,
   avg(i,:) = (origS*Mue(:,i))';
 end
 Na(Na > 0) = c;
 sig; 
